==> jc-1.4.0.tar.gz: java/nio/charset/MalformedInputException.h <==
// public class java.nio.charset.MalformedInputException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class c9c34a3e4ea2cab5 java_nio_charset_CharacterCodingException
// @dep_class ab8e40994c7a471 java_nio_charset_MalformedInputException

// header file dependencies
// @dep_header java_nio_charset_CharacterCodingException

#include "java/nio/charset/CharacterCodingException.h"

#ifndef _JC_java_nio_charset_MalformedInputException_H_
#define _JC_java_nio_charset_MalformedInputException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_nio_charset_MalformedInputException$sub_refs	_jc_java_nio_charset_MalformedInputException$sub_refs;
typedef struct _jc_java_nio_charset_MalformedInputException$sub_nonrefs	_jc_java_nio_charset_MalformedInputException$sub_nonrefs;
typedef struct _jc_java_nio_charset_MalformedInputException$refs	_jc_java_nio_charset_MalformedInputException$refs;
typedef struct _jc_java_nio_charset_MalformedInputException$nonrefs	_jc_java_nio_charset_MalformedInputException$nonrefs;
typedef struct _jc_java_nio_charset_MalformedInputException$object	_jc_java_nio_charset_MalformedInputException$object;

typedef const struct _jc_java_nio_charset_MalformedInputException$vmethods	_jc_java_nio_charset_MalformedInputException$vmethods;
typedef const struct _jc_java_nio_charset_MalformedInputException$vtable	_jc_java_nio_charset_MalformedInputException$vtable;
typedef const struct _jc_java_nio_charset_MalformedInputException$vtype	_jc_java_nio_charset_MalformedInputException$vtype;

// Constructors
extern void _jc_java_nio_charset_MalformedInputException$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_nio_charset_MalformedInputException$object *, jint);

// Virtual methods
extern jint _jc_java_nio_charset_MalformedInputException$method$getInputLength$471df90fb92db657(_jc_env *, struct _jc_java_nio_charset_MalformedInputException$object *);
extern struct _jc_java_lang_String$object *_jc_java_nio_charset_MalformedInputException$method$getMessage$13aaf240efc902b1(_jc_env *, struct _jc_java_nio_charset_MalformedInputException$object *);

// Virtual method descriptors
extern _jc_method _jc_java_nio_charset_MalformedInputException$method_info$getInputLength$471df90fb92db657;
extern _jc_method _jc_java_nio_charset_MalformedInputException$method_info$getMessage$13aaf240efc902b1;

// Virtual methods structure
struct _jc_java_nio_charset_MalformedInputException$vmethods {
	jint	(*getInputLength$471df90fb92db657)(_jc_env *, struct _jc_java_nio_charset_MalformedInputException$object *);
	struct _jc_java_lang_String$object	*(*getMessage$13aaf240efc902b1)(_jc_env *, struct _jc_java_nio_charset_MalformedInputException$object *);
};

// Vtable
struct _jc_java_nio_charset_MalformedInputException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_java_nio_charset_CharacterCodingException$vmethods	java_nio_charset_CharacterCodingException;
	_jc_java_nio_charset_MalformedInputException$vmethods	java_nio_charset_MalformedInputException;
};

// Vtype
struct _jc_java_nio_charset_MalformedInputException$vtype {
	_jc_type			type;
	_jc_java_nio_charset_MalformedInputException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_charset_MalformedInputException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_charset_MalformedInputException$refs {
    _jc_java_nio_charset_MalformedInputException$sub_refs	java_nio_charset_MalformedInputException;
    _jc_java_nio_charset_CharacterCodingException$sub_refs	java_nio_charset_CharacterCodingException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_charset_MalformedInputException$sub_nonrefs {
	jint	inputLength;
};

// Non-reference instance fields (object)
struct _jc_java_nio_charset_MalformedInputException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_java_nio_charset_CharacterCodingException$sub_nonrefs	java_nio_charset_CharacterCodingException;
    _jc_java_nio_charset_MalformedInputException$sub_nonrefs	java_nio_charset_MalformedInputException;
};

// Object instance structure
struct _jc_java_nio_charset_MalformedInputException$object {
	_jc_java_nio_charset_MalformedInputException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_charset_MalformedInputException$vtype	*vtype;
	_jc_java_nio_charset_MalformedInputException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_charset_MalformedInputException$vtype _jc_java_nio_charset_MalformedInputException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_charset_MalformedInputException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_charset_MalformedInputException$class_object;

#endif	/* _JC_java_nio_charset_MalformedInputException_H_ */

==> jc-1.4.6.tar.gz: java/nio/charset/MalformedInputException.h <==
// public class java.nio.charset.MalformedInputException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class c9c34a3e4ea2cab5 java_nio_charset_CharacterCodingException
// @dep_class ab8e40994c7a471 java_nio_charset_MalformedInputException

// header file dependencies
// @dep_header java_nio_charset_CharacterCodingException

#include "java/nio/charset/CharacterCodingException.h"

#ifndef _JC_java_nio_charset_MalformedInputException_H_
#define _JC_java_nio_charset_MalformedInputException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_nio_charset_MalformedInputException$sub_refs	_jc_java_nio_charset_MalformedInputException$sub_refs;
typedef struct _jc_java_nio_charset_MalformedInputException$sub_nonrefs	_jc_java_nio_charset_MalformedInputException$sub_nonrefs;
typedef struct _jc_java_nio_charset_MalformedInputException$refs	_jc_java_nio_charset_MalformedInputException$refs;
typedef struct _jc_java_nio_charset_MalformedInputException$nonrefs	_jc_java_nio_charset_MalformedInputException$nonrefs;
typedef struct _jc_java_nio_charset_MalformedInputException$object	_jc_java_nio_charset_MalformedInputException$object;

typedef const struct _jc_java_nio_charset_MalformedInputException$vmethods	_jc_java_nio_charset_MalformedInputException$vmethods;
typedef const struct _jc_java_nio_charset_MalformedInputException$vtable	_jc_java_nio_charset_MalformedInputException$vtable;
typedef const struct _jc_java_nio_charset_MalformedInputException$vtype	_jc_java_nio_charset_MalformedInputException$vtype;

// Constructors
extern void _jc_java_nio_charset_MalformedInputException$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_nio_charset_MalformedInputException$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_java_nio_charset_MalformedInputException$method$getInputLength$471df90fb92db657(_jc_env *, struct _jc_java_nio_charset_MalformedInputException$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_nio_charset_MalformedInputException$method$getMessage$13aaf240efc902b1(_jc_env *, struct _jc_java_nio_charset_MalformedInputException$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_nio_charset_MalformedInputException$method_info$getInputLength$471df90fb92db657;
extern _jc_method _jc_java_nio_charset_MalformedInputException$method_info$getMessage$13aaf240efc902b1;

// Virtual methods structure
struct _jc_java_nio_charset_MalformedInputException$vmethods {
	jint	(*getInputLength$471df90fb92db657)(_jc_env *, struct _jc_java_nio_charset_MalformedInputException$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getMessage$13aaf240efc902b1)(_jc_env *, struct _jc_java_nio_charset_MalformedInputException$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_nio_charset_MalformedInputException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_java_nio_charset_CharacterCodingException$vmethods	java_nio_charset_CharacterCodingException;
	_jc_java_nio_charset_MalformedInputException$vmethods	java_nio_charset_MalformedInputException;
};

// Vtype
struct _jc_java_nio_charset_MalformedInputException$vtype {
	_jc_type			type;
	_jc_java_nio_charset_MalformedInputException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_charset_MalformedInputException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_charset_MalformedInputException$refs {
    _jc_java_nio_charset_MalformedInputException$sub_refs	java_nio_charset_MalformedInputException;
    _jc_java_nio_charset_CharacterCodingException$sub_refs	java_nio_charset_CharacterCodingException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_charset_MalformedInputException$sub_nonrefs {
	jint	inputLength;
};

// Non-reference instance fields (object)
struct _jc_java_nio_charset_MalformedInputException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_java_nio_charset_CharacterCodingException$sub_nonrefs	java_nio_charset_CharacterCodingException;
    _jc_java_nio_charset_MalformedInputException$sub_nonrefs	java_nio_charset_MalformedInputException;
};

// Object instance structure
struct _jc_java_nio_charset_MalformedInputException$object {
	_jc_java_nio_charset_MalformedInputException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_charset_MalformedInputException$vtype	*vtype;
	_jc_java_nio_charset_MalformedInputException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_charset_MalformedInputException$vtype _jc_java_nio_charset_MalformedInputException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_charset_MalformedInputException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_charset_MalformedInputException$class_object;

#endif	/* _JC_java_nio_charset_MalformedInputException_H_ */
